@@ -27,6 +27,7 @@ from pytorch_lightning.utilities.distributed import all_gather_ddp_if_available,
 
 
 class ParallelPlugin(TrainingTypePlugin, ABC):
+    """ Plugin for training with multiple processes in parallel. """
 
     def __init__(
         self,
@@ -50,14 +51,6 @@ class ParallelPlugin(TrainingTypePlugin, ABC):
     def lightning_module(self):
         return unwrap_lightning_module(self._model)
 
-    @abstractmethod
-    def setup(self, model):
-        raise NotImplementedError
-
-    def connect(self, model, *args, **kwargs):
-        self.setup(model)
-        return self.model
-
     @property
     def global_rank(self) -> int:
         return self.cluster_environment.global_rank() if self.cluster_environment is not None else 0
